@@ -1,10 +1,12 @@
 import platform
+import random
 import subprocess
 import sys
 from contextlib import contextmanager
 from itertools import chain
 from pathlib import Path
 from tempfile import NamedTemporaryFile
+from textwrap import dedent
 
 try:
     from unittest import mock
@@ -304,6 +306,85 @@ def test_render_text(capsys, list_all, reverse, expected_output):
 # Tests for graph outputs
 
 
+def randomized_dag_copy(t):
+    """Returns a copy of the package tree fixture with dependencies in randomized order."""
+    # Extract the dependency graph from the package tree and randomize it.
+    randomized_graph = {}
+    randomized_nodes = list(t._obj.keys())
+    random.shuffle(randomized_nodes)
+    for node in randomized_nodes:
+        edges = t._obj[node]
+        random.shuffle(edges)
+        randomized_graph[node] = edges
+    assert set(randomized_graph) == set(t._obj)
+
+    # Create a randomized package tree.
+    randomized_dag = p.PackageDAG(randomized_graph)
+    assert len(t) == len(randomized_dag)
+    return randomized_dag
+
+
+def test_render_mermaid():
+    # Check both the sorted and randomized package tree produces the same sorted
+    # Mermaid output.
+    for package_tree in (t, randomized_dag_copy(t)):
+        output = p.render_mermaid(package_tree)
+        assert output == dedent(
+            """\
+            flowchart TD
+                classDef missing stroke-dasharray: 5
+                a[a\\n3.4.0]
+                b[b\\n2.3.1]
+                c[c\\n5.10.0]
+                d[d\\n2.35]
+                e[e\\n0.12.1]
+                f[f\\n3.1]
+                g[g\\n6.8.3rc1]
+                a -- >=2.0.0 --> b
+                a -- >=5.7.1 --> c
+                b -- >=2.30,<2.42 --> d
+                c -- >=0.12.1 --> e
+                c -- >=2.30 --> d
+                d -- >=0.9.0 --> e
+                f -- >=2.1.0 --> b
+                g -- >=0.9.0 --> e
+                g -- >=3.0.0 --> f
+            """
+        )
+
+
+def test_render_dot(capsys):
+    # Check both the sorted and randomized package tree produces the same sorted
+    # graphviz output.
+    for package_tree in (t, randomized_dag_copy(t)):
+        output = p.dump_graphviz(package_tree, output_format="dot")
+        p.print_graphviz(output)
+        out, _ = capsys.readouterr()
+        assert out == dedent(
+            """\
+            digraph {
+            \ta -> b [label=">=2.0.0"]
+            \ta -> c [label=">=5.7.1"]
+            \ta [label="a\\n3.4.0"]
+            \tb -> d [label=">=2.30,<2.42"]
+            \tb [label="b\\n2.3.1"]
+            \tc -> d [label=">=2.30"]
+            \tc -> e [label=">=0.12.1"]
+            \tc [label="c\\n5.10.0"]
+            \td -> e [label=">=0.9.0"]
+            \td [label="d\\n2.35"]
+            \te [label="e\\n0.12.1"]
+            \tf -> b [label=">=2.1.0"]
+            \tf [label="f\\n3.1"]
+            \tg -> e [label=">=0.9.0"]
+            \tg -> f [label=">=3.0.0"]
+            \tg [label="g\\n6.8.3rc1"]
+            }
+
+            """
+        )
+
+
 def test_render_pdf():
     output = p.dump_graphviz(t, output_format="pdf")
 
@@ -451,6 +532,14 @@ def test_parser_json_tree():
     assert args.output_format is None
 
 
+def test_parser_mermaid():
+    parser = p.get_parser()
+    args = parser.parse_args(["--mermaid"])
+    assert args.mermaid
+    assert not args.json
+    assert args.output_format is None
+
+
 def test_parser_pdf():
     parser = p.get_parser()
     args = parser.parse_args(["--graph-output", "pdf"])
